@@ -8,12 +8,17 @@
 
 #include <ncurses.h>   /* or curses.h */
 
-#ifdef C_PANELSUPPORT
+#ifdef C_PANELFUNCTION
 #include <panel.h>
 #endif
 
-/* Defined in both Perl & Ncurses */
-#undef instr
+#ifdef C_MENUFUNCTION
+#include <menu.h>
+#endif
+
+#ifdef C_FORMFUNCTION
+#include <form.h>
+#endif
 
 #define C_LONGNAME
 #define C_LONG0ARGS
